@@ -1,7 +1,7 @@
 from typing import List, Optional, Mapping, Union
 
 import tensorflow as tf
-from tensorflow import keras
+import tensorflow.keras as keras
 
 from sfu_ml_lib.base.metrics import Metric
 from sfu_ml_lib.metrics.error import CutoffThreshold
