@@ -22,7 +22,7 @@ class Mean(Metric):
 
     def update_mean(self, values: Tensor, batch_size: Tensor) -> None:
         new_count = self.count + batch_size
-        new_mean = (tf.reduce_sum(values) + self.count * self.mean) / new_count
+        new_mean = self.mean + tf.reduce_sum(values - self.mean) / new_count
 
         self.mean.assign(new_mean)
 
